@@ -19,5 +19,5 @@ class SplTokenViewerApiClient(object):
         response = requests.get(
             '{}/fetch_nft_data'.format(self.base_url),
             data=params)
-        return response.json()['nfts']
+        return response.json()
 
